@@ -347,7 +347,9 @@ class ModelTorchAdapter(Model):
 
     def predict(self, input, get_likelihood=False, returnNumpy=True):
         with torch.no_grad():
-            input = torch.from_numpy(input)
+            if not torch.is_tensor(input):
+                input = torch.tensor(input)
+ 
             batchSize, _, _ = input.shape
 
             if self.useGPU:
