@@ -266,7 +266,7 @@ class Scorer:
             predictionSoftMax = e_x / sum
             classLikelyhood = predictionSoftMax[:, 1]
         else:
-            classLikelyhood = max
+            classLikelyhood = max.reshape(-1)
         return classLikelyhood
 
     def getClassPrediction(self, prediction):
